==> pyroherd-0.0.1-py3-none-any.whl: pyroherd/raw/base/input_privacy_key.py <==
#  Pyroherd - Telegram MTProto API Client Library for Python
#  Copyright (C) 2023-present OnTheHerd <https://github.com/OnTheHerd>
#
#  This file is part of Pyroherd.
#
#  Pyroherd is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyroherd is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyroherd.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyroherd import raw
from pyroherd.raw.core import TLObject

InputPrivacyKey = Union[raw.types.InputPrivacyKeyAddedByPhone, raw.types.InputPrivacyKeyChatInvite, raw.types.InputPrivacyKeyForwards, raw.types.InputPrivacyKeyPhoneCall, raw.types.InputPrivacyKeyPhoneNumber, raw.types.InputPrivacyKeyPhoneP2P, raw.types.InputPrivacyKeyProfilePhoto, raw.types.InputPrivacyKeyStatusTimestamp]


# noinspection PyRedeclaration
class InputPrivacyKey:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputPrivacyKeyAddedByPhone <pyroherd.raw.types.InputPrivacyKeyAddedByPhone>`
            - :obj:`InputPrivacyKeyChatInvite <pyroherd.raw.types.InputPrivacyKeyChatInvite>`
            - :obj:`InputPrivacyKeyForwards <pyroherd.raw.types.InputPrivacyKeyForwards>`
            - :obj:`InputPrivacyKeyPhoneCall <pyroherd.raw.types.InputPrivacyKeyPhoneCall>`
            - :obj:`InputPrivacyKeyPhoneNumber <pyroherd.raw.types.InputPrivacyKeyPhoneNumber>`
            - :obj:`InputPrivacyKeyPhoneP2P <pyroherd.raw.types.InputPrivacyKeyPhoneP2P>`
            - :obj:`InputPrivacyKeyProfilePhoto <pyroherd.raw.types.InputPrivacyKeyProfilePhoto>`
            - :obj:`InputPrivacyKeyStatusTimestamp <pyroherd.raw.types.InputPrivacyKeyStatusTimestamp>`
    """

    QUALNAME = "pyroherd.raw.base.InputPrivacyKey"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyroherd.org/telegram/base/input-privacy-key")

==> pyroherd-0.0.3-py3-none-any.whl: pyroherd/raw/base/input_privacy_key.py <==
#  Pyroherd - Telegram MTProto API Client Library for Python
#  Copyright (C) 2023-present OnTheHerd <https://github.com/OnTheHerd>
#
#  This file is part of Pyroherd.
#
#  Pyroherd is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyroherd is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyroherd.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyroherd import raw
from pyroherd.raw.core import TLObject

InputPrivacyKey = Union[raw.types.InputPrivacyKeyAddedByPhone, raw.types.InputPrivacyKeyChatInvite, raw.types.InputPrivacyKeyForwards, raw.types.InputPrivacyKeyPhoneCall, raw.types.InputPrivacyKeyPhoneNumber, raw.types.InputPrivacyKeyPhoneP2P, raw.types.InputPrivacyKeyProfilePhoto, raw.types.InputPrivacyKeyStatusTimestamp, raw.types.InputPrivacyKeyVoiceMessages]


# noinspection PyRedeclaration
class InputPrivacyKey:  # type: ignore
    """This base type has 9 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputPrivacyKeyAddedByPhone <pyroherd.raw.types.InputPrivacyKeyAddedByPhone>`
            - :obj:`InputPrivacyKeyChatInvite <pyroherd.raw.types.InputPrivacyKeyChatInvite>`
            - :obj:`InputPrivacyKeyForwards <pyroherd.raw.types.InputPrivacyKeyForwards>`
            - :obj:`InputPrivacyKeyPhoneCall <pyroherd.raw.types.InputPrivacyKeyPhoneCall>`
            - :obj:`InputPrivacyKeyPhoneNumber <pyroherd.raw.types.InputPrivacyKeyPhoneNumber>`
            - :obj:`InputPrivacyKeyPhoneP2P <pyroherd.raw.types.InputPrivacyKeyPhoneP2P>`
            - :obj:`InputPrivacyKeyProfilePhoto <pyroherd.raw.types.InputPrivacyKeyProfilePhoto>`
            - :obj:`InputPrivacyKeyStatusTimestamp <pyroherd.raw.types.InputPrivacyKeyStatusTimestamp>`
            - :obj:`InputPrivacyKeyVoiceMessages <pyroherd.raw.types.InputPrivacyKeyVoiceMessages>`
    """

    QUALNAME = "pyroherd.raw.base.InputPrivacyKey"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyroherd.org/telegram/base/input-privacy-key")
